@@ -8,8 +8,6 @@
 
 #define QT_FEATURE_futimens -1
 
-#define QT_FEATURE_futimes -1
-
 #define QT_FEATURE_getauxval -1
 
 #define QT_FEATURE_getentropy -1
@@ -64,5 +62,9 @@
 
 #define QT_FEATURE_etw -1
 
+#define QT_FEATURE_ctf -1
+
 #define QT_FEATURE_forkfd_pidfd -1
 
+#define QT_FEATURE_poll_exit_on_error -1
+
